@@ -4,7 +4,7 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-# Version: $Id: Mail.pm,v 1.32 2001/09/08 08:34:47 parkerpine Exp $
+# Version: $Id: Mail.pm,v 1.33 2001/09/09 09:02:43 parkerpine Exp $
 
 package Mail::MboxParser::Mail;
 
@@ -18,7 +18,7 @@ use Carp;
 use strict;
 use base qw(Exporter);
 use vars qw($VERSION @EXPORT @ISA $AUTOLOAD);
-$VERSION    = "0.17";
+$VERSION    = "0.18";
 @EXPORT     = qw();
 @ISA		= qw(Mail::MboxParser::Base);
 $^W++;
@@ -41,9 +41,10 @@ sub init (@) {
 
 sub header() {
 	my $self = shift;
+    my $decode = $self->{ARGS}->{decode} || 'NEVER';
 	$self->reset_last;
 	
-	return $self->{HEADER_HASH}->($self->{HEADER});
+	return $self->{HEADER_HASH}->($self->{HEADER}, $decode);
 }
 
 sub body(;$) { 
@@ -108,7 +109,6 @@ sub make_convertable(@) {
 sub from() {
 	my $self = shift;
 	$self->reset_last;
-	my $decode = $self->{ARGS}->{decode} || 'NEVER';
 	
 	my $from = $self->header->{from};
 	my ($name, $email) = split /\s\</, $from;
@@ -117,12 +117,6 @@ sub from() {
 		$email = $name;
 		$name  = "";
 	}
-	
-	if ($decode eq 'HEADER' || $decode eq 'ALL') { 
-		use MIME::Words qw(:all);
-		$name = decode_mimewords($name);
-	}
-
 	return {(name => $name, email => $email)};
 }
 
@@ -288,16 +282,6 @@ EOW
 	return @files;
 }
 
-# --------------------
-# spam-related methods
-# --------------------
-
-sub is_spam(;@) {
-	my ($self, %args) = @_; 
-	my $detector	= Mail::MboxParser::SpamDetector->new($self, %args);
-	return $detector->classify;
-}
-
 sub as_string {
 	my $self = shift;
 	return $self->{HEADER}.$self->{BODY};
@@ -306,7 +290,6 @@ sub as_string {
 sub _recipients($) {
 	my ($self, $field) = @_;
 	$self->reset_last;
-	my $decode = $self->{ARGS}->{decode} || 'NEVER';
 	
 	my $rec = $self->header->{$field};
 	if (not $rec) {
@@ -327,17 +310,12 @@ sub _recipients($) {
 		push @rec_line, {(name => $name, email => $email)};
 	}
 	
-	if ($decode eq 'HEADER' || $decode eq 'ALL') {
-		use MIME::Words qw(:all);
-		map { $_->{name} = decode_mimewords($_->{name}) } @rec_line;
-	}
-	
 	return @rec_line;
 }
 
 # patch provided by Kenn Frankel
 sub split_header {
-	my $header = shift;
+	my ($header, $decode) = @_;
 	my @headerlines = split /\n/, $header;
 	my @header;
  	foreach my $bit (@headerlines) {
@@ -351,6 +329,10 @@ sub split_header {
 		unless (/^Received:\s/ or not /: /) {
 			$key   = substr $_, 0, index($_, ": ");
 			$value = substr $_, index($_, ": ") + 2;
+            if ($decode eq 'ALL' || $decode eq 'HEADER') {
+                use MIME::Words qw(:all);
+                $value = decode_mimewords($value); 
+            }
 			$header{lc($key)} = $value;
 		}
 	}
@@ -416,6 +398,143 @@ Mail::MboxParser::Mail objects are usually not created directly though, in theor
 
 However, go on reading if you want to use methods from MIME::Entity and learn about overloading.
 
+=head1 METHODS
+
+=over 4
+
+=item B<new(header, body)>
+
+This is usually not called directly but instead by get_messages(). You could however create a mail-object manually providing the header and body both as one string.
+
+=item B<header>
+
+Returns the mail-header as a hash-ref with header-fields as keys. All keys are turned to lower-case, so $header{Subject} has to be written as $header{subject}.
+
+=item B<body>
+
+=item B<body(n)>
+
+Returns a Mail::MboxParser::Mail::Body object. For methods upon that see further below. When called with the argument n, the n-th body of the message is retrieved. That is, the body of the n-th entity.
+
+Sets $message->error if something went wrong.
+
+=item B<find_body>
+
+This will return an index number that represents what Mail::MboxParser considers to be the actual (main)-body of an email. This is useful if you don't know about the structure of a message but want to retrieve the message's signature for instance:
+
+	$signature = $msg->body($msg->find_body)->signature;
+
+Changes are good that find_body does what it is supposed to do.
+	
+=item B<from>
+
+Returns a hash-ref with the two fields 'name' and 'email'. Returns undef if empty. The name-field does not necessarily contain a value either. Example:
+	
+	print $mail->from->{email};
+
+=item B<to>
+
+Returns an array of hash-references of all to-fields in the mail-header. Fields are the same as those of $mail->from. Example:
+
+	for my $recipient ($mail->to) {
+		print $recipient->{name} || "<no name>", "\n";
+		print $recipient->{email};
+	}
+
+=item B<cc>
+
+Identical with to() but returning the hash-refed "Cc: "-line.
+
+=item B<id>
+
+Returns the message-id of a message cutting off the leading and trailing '<' and '>' respectively.
+
+=item B<num_entitities>
+
+Returns the number of MIME-entities. That is, the number of sub-entitities actually. If 0 is returned and you think this is wrong, check $mail->log.
+
+=item B<get_entities>
+
+=item B<get_entities(n)>
+
+Either returns an array of all MIME::Entity objects or one particular if called with a number. If no entity whatsoever could be found, an empty list is returned.
+
+$mail->log instantly called after get_entities will give you some information of what internally may have failed. If set, this will be an error raised by MIME::Entity but you don't need to worry about it at all. It's just for the record.
+
+=item B<get_entity_body(n)>
+
+Returns the body of the n-th MIME::Entity as a single string, undef otherwise in which case you could check $mail->error.
+
+=item B<store_entity_body(n, handle =E<gt> FILEHANDLE)>
+
+Stores the stringified body of n-th entity to the specified filehandle. That's basically the same as:
+
+ my $body = $mail->get_entity_body(0);
+ print FILEHANDLE $body;
+
+and could be shortened to this:
+
+ $mail->store_entity_body(0, handle => \*FILEHANDLE);
+
+It returns a true value on success and undef on failure. In this case, examine the value of $mail->error since the entity you specified with 'n' might not exist.
+
+=item B<store_attachement(n)>
+
+=item B<store_attachement(n, options)>
+
+It is really just a call to store_entity_body but it will take care that the n-th entity really is a saveable attachement. That is, it wont save anything with a MIME-type of, say, text/html or so. 
+
+Unless further 'options' have been given, an attachement (if found) is stored into the current directory under the recommended filename given in the MIME-header. 'options' are specified in key/value pairs:
+
+    key:      | value:       | description:
+    ==========|==============|===============================
+    path      | relative or  | directory to store attachement
+    (".")     | absolute     |
+              | path         |
+    ==========|==============|===============================
+    code      | an anonym    | first argument will be the 
+              | subroutine   | $msg-object, second one the 
+              |              | index-number of the current
+              |              | MIME-part
+              |              | should return a filename for
+              |              | the attachement
+    ==========|==============|===============================
+    args      | additional   | this array-ref will be passed  
+              | arguments as | on to the 'code' subroutine
+              | array-ref    | as a dereferenced array
+
+Example:
+
+ 	$msg->store_attachement(1, 
+                            path => "/home/ethan/", 
+                            code => sub {
+                                        my ($msg, $n, @args) = @_;
+                                        return $msg->id."+$n";
+                                        },
+                            args => [ "Foo", "Bar" ]);
+
+This will save the attachement found in the second entity under the name that consists of the message-ID and the appendix "+1" since the above code works on the second entity (that is, with index = 1). 'args' isn't used in this example but should demonstrate how to pass additional arguments. Inside the 'code' sub, @args equals ("Foo", "Bar").
+
+If 'path' does not exist, it will try to create the directory for you.
+
+Returns the filename under which the attachement has been saved. undef is returned in case the entity did not contain a saveable attachement, there was no such entity at all or there was something wrong with the 'path' you specified. Check $mail->error to find out which of these possibilities appliy.
+
+=item B<store_all_attachements>
+
+=item B<store_all_attachements(options)>
+
+Walks through an entire mail and stores all apparent attachements. 'options' are exactly the same as in store_attachement() with the same behaviour if no options are given. 
+
+Returns a list of files that has been succesfully saved and an empty list if no attachement could be extracted.
+
+$mail->error will tell you possible failures and a possible explanation for that.
+
+=item B<make_convertable>
+
+Returns a Mail::MboxParser::Mail::Convertable object. For details on what you can do with it, read L<Mail::MboxParser::Mail::Convertable>.
+
+=back
+
 =head1 EXTERNAL METHODS
 
 Mail::MboxParser::Mail implements an autoloader that will do the appropriate type-casts for you if you invoke methods from external modules. This, however, currently only works with MIME::Entity. Support for other modules will follow.
@@ -445,6 +564,4 @@ modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Mail::MboxParser> for a description of methods
-
 =cut
